searchData={"items":[{"type":"module","doc":"`Ecto.DateTimeRange` provides modules implementing `Ecto.Type` to allow\nusage of Postgres range times encoding timestamp ranges.","title":"Ecto.DateTimeRange","ref":"Ecto.DateTimeRange.html"},{"type":"function","doc":"Create an `Ecto.UTCDateTimeRange` from two ISO8601 strings.","title":"Ecto.DateTimeRange.sigil_t/2","ref":"Ecto.DateTimeRange.html#sigil_t/2"},{"type":"function","doc":"```\niex> import Ecto.DateTimeRange, only: [sigil_t: 2]\n...>\niex> ~t(2020-02-02T00:01:00Z..2020-02-02T00:01:01Z)\n%Ecto.DateTimeRange.UTCDateTime{start_at: ~U[2020-02-02T00:01:00Z], end_at: ~U[2020-02-02T00:01:01Z]}\n...>\niex> ~t(2020-02-02T00:01:00Z..2020-02-02T00:01:01Z)U\n%Ecto.DateTimeRange.UTCDateTime{start_at: ~U[2020-02-02T00:01:00Z], end_at: ~U[2020-02-02T00:01:01Z]}\n...>\niex> ~t(2020-02-02T00:01:00..2020-02-02T00:01:01)N\n%Ecto.DateTimeRange.NaiveDateTime{start_at: ~N[2020-02-02T00:01:00], end_at: ~N[2020-02-02T00:01:01]}\n...>\niex> ~t(00:01:00..00:01:01)T\n%Ecto.DateTimeRange.Time{start_at: ~T[00:01:00], end_at: ~T[00:01:01]}\n...>\niex> ~t(hi there)\n** (ArgumentError) Unable to parse DateTime(s) from input\n```","title":"Example - Ecto.DateTimeRange.sigil_t/2","ref":"Ecto.DateTimeRange.html#sigil_t/2-example"},{"type":"module","doc":"An `Ecto.Type` wrapping a `:tsrange` Postgres column. To the application, it appears as\na struct with `:start_at` and `:end_at`, with `:naive_datetime` values.\n\n```\ndefmodule Core.Thing do\n  use Ecto.Schema\n  import Ecto.Changeset\n\n  schema \"things\" do\n    field :performed_during, Ecto.DateTimeRange.NaiveDateTime\n  end\n\n  @required_attrs ~w[performed_during]a\n  def changeset(data \\ %__MODULE__{}, attrs) do\n    data\n    |> cast(attrs, @required_attrs)\n    |> validate_required(@required_attrs)\n  end\nend\n```","title":"Ecto.DateTimeRange.NaiveDateTime","ref":"Ecto.DateTimeRange.NaiveDateTime.html"},{"type":"function","doc":"Converts user-provided data (for example from a form) to the Elixir term.","title":"Ecto.DateTimeRange.NaiveDateTime.cast/1","ref":"Ecto.DateTimeRange.NaiveDateTime.html#cast/1"},{"type":"function","doc":"Returns true or false depending on whether the time is falls within the\nspecified range.","title":"Ecto.DateTimeRange.NaiveDateTime.contains?/2","ref":"Ecto.DateTimeRange.NaiveDateTime.html#contains?/2"},{"type":"function","doc":"```\niex> import Ecto.DateTimeRange\niex> range = ~t[2020-01-01T01:00:00..2020-01-02T01:00:00]N\n...>\niex> Ecto.DateTimeRange.NaiveDateTime.contains?(range, ~N[2020-01-01T00:59:59Z])\nfalse\niex> Ecto.DateTimeRange.NaiveDateTime.contains?(range, ~N[2020-01-01T01:00:00Z])\ntrue\niex> Ecto.DateTimeRange.NaiveDateTime.contains?(range, ~N[2020-01-02T00:59:59Z])\ntrue\niex> Ecto.DateTimeRange.NaiveDateTime.contains?(range, ~N[2020-01-02T01:00:00Z])\nfalse\niex> Ecto.DateTimeRange.NaiveDateTime.contains?(range, ~N[2020-01-03T01:00:00Z])\nfalse\n```","title":"Example - Ecto.DateTimeRange.NaiveDateTime.contains?/2","ref":"Ecto.DateTimeRange.NaiveDateTime.html#contains?/2-example"},{"type":"function","doc":"Converts the Elixir term to the Ecto native type.","title":"Ecto.DateTimeRange.NaiveDateTime.dump/1","ref":"Ecto.DateTimeRange.NaiveDateTime.html#dump/1"},{"type":"function","doc":"Declares than when used in embedded schemas, the type will be dumped before being encoded.","title":"Ecto.DateTimeRange.NaiveDateTime.embed_as/1","ref":"Ecto.DateTimeRange.NaiveDateTime.html#embed_as/1"},{"type":"function","doc":"Checks if two terms are equal.","title":"Ecto.DateTimeRange.NaiveDateTime.equal?/2","ref":"Ecto.DateTimeRange.NaiveDateTime.html#equal?/2"},{"type":"function","doc":"Converts the Ecto native type to the Elixir term.","title":"Ecto.DateTimeRange.NaiveDateTime.load/1","ref":"Ecto.DateTimeRange.NaiveDateTime.html#load/1"},{"type":"function","doc":"Create an `Ecto.DateTimeRange.NaiveDateTime` from two ISO8601 strings.","title":"Ecto.DateTimeRange.NaiveDateTime.parse/1","ref":"Ecto.DateTimeRange.NaiveDateTime.html#parse/1"},{"type":"function","doc":"```\niex> Ecto.DateTimeRange.NaiveDateTime.parse(\"2020-02-02T00:01:00..2020-02-02T00:01:01\")\n{:ok, %Ecto.DateTimeRange.NaiveDateTime{start_at: ~N[2020-02-02T00:01:00], end_at: ~N[2020-02-02T00:01:01]}}\n\niex> Ecto.DateTimeRange.NaiveDateTime.parse(\"2020-02-02T00:01:00..later\")\n{:error, \"Unable to parse NaiveDateTime(s) from input\"}\n```","title":"Example - Ecto.DateTimeRange.NaiveDateTime.parse/1","ref":"Ecto.DateTimeRange.NaiveDateTime.html#parse/1-example"},{"type":"type","doc":"","title":"Ecto.DateTimeRange.NaiveDateTime.t/0","ref":"Ecto.DateTimeRange.NaiveDateTime.html#t:t/0"},{"type":"function","doc":"Declares the native type that will be used in the database.","title":"Ecto.DateTimeRange.NaiveDateTime.type/0","ref":"Ecto.DateTimeRange.NaiveDateTime.html#type/0"},{"type":"module","doc":"An `Ecto.Type` wrapping a `:tsrange` Postgres column. To the application, it appears as\na struct with `:start_at` and `:end_at`, with `t:Time.t()` values.\n\nThis type does not do any time zone conversions--times going in will be times coming out.\n\n```\ndefmodule Core.Thing do\n  use Ecto.Schema\n  import Ecto.Changeset\n\n  schema \"things\" do\n    field :performed_during, Ecto.DateTimeRange.Time\n  end\n\n  @required_attrs ~w[performed_during]a\n  def changeset(data \\ %__MODULE__{}, attrs) do\n    data\n    |> cast(attrs, @required_attrs)\n    |> validate_required(@required_attrs)\n  end\nend\n```","title":"Ecto.DateTimeRange.Time","ref":"Ecto.DateTimeRange.Time.html"},{"type":"function","doc":"Converts user-provided data (for example from a form) to the Elixir term.","title":"Ecto.DateTimeRange.Time.cast/1","ref":"Ecto.DateTimeRange.Time.html#cast/1"},{"type":"function","doc":"Returns true or false depending on whether the time is falls within the\nspecified range. **Note:** this assumes that the range is in the same time zone as\nwhatever time or date time it is compared against.","title":"Ecto.DateTimeRange.Time.contains?/2","ref":"Ecto.DateTimeRange.Time.html#contains?/2"},{"type":"function","doc":"```\niex> import Ecto.DateTimeRange\n...>\niex> Ecto.DateTimeRange.Time.contains?(~t[01:00:00..02:00:00]T, ~T[00:00:00])\nfalse\niex> Ecto.DateTimeRange.Time.contains?(~t[01:00:00..02:00:00]T, ~T[01:00:00])\ntrue\niex> Ecto.DateTimeRange.Time.contains?(~t[01:00:00..02:00:00]T, ~T[01:59:59])\ntrue\niex> Ecto.DateTimeRange.Time.contains?(~t[01:00:00..02:00:00]T, ~T[02:00:00])\nfalse\n...>\niex> Ecto.DateTimeRange.Time.contains?(~t[01:00:00..02:00:00]T, ~N[2022-01-01T00:00:00])\nfalse\niex> Ecto.DateTimeRange.Time.contains?(~t[01:00:00..02:00:00]T, ~N[2022-01-01T01:00:00])\ntrue\n...>\niex> Ecto.DateTimeRange.Time.contains?(~t[01:00:00..02:00:00]T, ~U[2022-01-01T00:00:00Z])\nfalse\niex> Ecto.DateTimeRange.Time.contains?(~t[01:00:00..02:00:00]T, ~U[2022-01-01T01:00:00Z])\ntrue\n```","title":"Example - Ecto.DateTimeRange.Time.contains?/2","ref":"Ecto.DateTimeRange.Time.html#contains?/2-example"},{"type":"function","doc":"Converts the Elixir term to the Ecto native type.","title":"Ecto.DateTimeRange.Time.dump/1","ref":"Ecto.DateTimeRange.Time.html#dump/1"},{"type":"function","doc":"Declares than when used in embedded schemas, the type will be dumped before being encoded.","title":"Ecto.DateTimeRange.Time.embed_as/1","ref":"Ecto.DateTimeRange.Time.html#embed_as/1"},{"type":"function","doc":"Checks if two terms are equal.","title":"Ecto.DateTimeRange.Time.equal?/2","ref":"Ecto.DateTimeRange.Time.html#equal?/2"},{"type":"function","doc":"Converts the Ecto native type to the Elixir term.","title":"Ecto.DateTimeRange.Time.load/1","ref":"Ecto.DateTimeRange.Time.html#load/1"},{"type":"function","doc":"Create an `Ecto.DateTimeRange.Time` from two ISO8601 strings.","title":"Ecto.DateTimeRange.Time.parse/1","ref":"Ecto.DateTimeRange.Time.html#parse/1"},{"type":"function","doc":"```\niex> Ecto.DateTimeRange.Time.parse(\"00:01:00..00:01:01\")\n{:ok, %Ecto.DateTimeRange.Time{start_at: ~T[00:01:00], end_at: ~T[00:01:01]}}\n\niex> Ecto.DateTimeRange.Time.parse(\"00:01:00..later\")\n{:error, \"Unable to parse Time(s) from input\"}\n```","title":"Example - Ecto.DateTimeRange.Time.parse/1","ref":"Ecto.DateTimeRange.Time.html#parse/1-example"},{"type":"type","doc":"","title":"Ecto.DateTimeRange.Time.t/0","ref":"Ecto.DateTimeRange.Time.html#t:t/0"},{"type":"function","doc":"Declares the native type that will be used in the database.","title":"Ecto.DateTimeRange.Time.type/0","ref":"Ecto.DateTimeRange.Time.html#type/0"},{"type":"module","doc":"An `Ecto.Type` wrapping a `:tstzrange` Postgres column. To the application, it appears as\na struct with `:start_at` and `:end_at`, with `:utc_datetime` values.\n\n```\ndefmodule Core.Thing do\n  use Ecto.Schema\n  import Ecto.Changeset\n\n  schema \"things\" do\n    field :performed_during, Ecto.DateTimeRange.UTCDateTime\n  end\n\n  @required_attrs ~w[performed_during]a\n  def changeset(data \\ %__MODULE__{}, attrs) do\n    data\n    |> cast(attrs, @required_attrs)\n    |> validate_required(@required_attrs)\n  end\nend\n```","title":"Ecto.DateTimeRange.UTCDateTime","ref":"Ecto.DateTimeRange.UTCDateTime.html"},{"type":"function","doc":"Converts user-provided data (for example from a form) to the Elixir term.","title":"Ecto.DateTimeRange.UTCDateTime.cast/1","ref":"Ecto.DateTimeRange.UTCDateTime.html#cast/1"},{"type":"function","doc":"Returns true or false depending on whether the time is falls within the\nspecified range.","title":"Ecto.DateTimeRange.UTCDateTime.contains?/2","ref":"Ecto.DateTimeRange.UTCDateTime.html#contains?/2"},{"type":"function","doc":"```\niex> import Ecto.DateTimeRange\niex> range = ~t[2020-01-01T01:00:00Z..2020-01-02T01:00:00Z]U\n...>\niex> Ecto.DateTimeRange.UTCDateTime.contains?(range, ~U[2020-01-01T00:59:59Z])\nfalse\niex> Ecto.DateTimeRange.UTCDateTime.contains?(range, ~U[2020-01-01T01:00:00Z])\ntrue\niex> Ecto.DateTimeRange.UTCDateTime.contains?(range, ~U[2020-01-02T00:59:59Z])\ntrue\niex> Ecto.DateTimeRange.UTCDateTime.contains?(range, ~U[2020-01-02T01:00:00Z])\nfalse\niex> Ecto.DateTimeRange.UTCDateTime.contains?(range, ~U[2020-01-03T01:00:00Z])\nfalse\n```","title":"Example - Ecto.DateTimeRange.UTCDateTime.contains?/2","ref":"Ecto.DateTimeRange.UTCDateTime.html#contains?/2-example"},{"type":"function","doc":"Converts the Elixir term to the Ecto native type.","title":"Ecto.DateTimeRange.UTCDateTime.dump/1","ref":"Ecto.DateTimeRange.UTCDateTime.html#dump/1"},{"type":"function","doc":"Declares than when used in embedded schemas, the type will be dumped before being encoded.","title":"Ecto.DateTimeRange.UTCDateTime.embed_as/1","ref":"Ecto.DateTimeRange.UTCDateTime.html#embed_as/1"},{"type":"function","doc":"Checks if two terms are equal.","title":"Ecto.DateTimeRange.UTCDateTime.equal?/2","ref":"Ecto.DateTimeRange.UTCDateTime.html#equal?/2"},{"type":"function","doc":"Converts the Ecto native type to the Elixir term.","title":"Ecto.DateTimeRange.UTCDateTime.load/1","ref":"Ecto.DateTimeRange.UTCDateTime.html#load/1"},{"type":"function","doc":"Create an `Ecto.DateTimeRange.UTCDateTime` from two ISO8601 strings.","title":"Ecto.DateTimeRange.UTCDateTime.parse/1","ref":"Ecto.DateTimeRange.UTCDateTime.html#parse/1"},{"type":"function","doc":"```\niex> Ecto.DateTimeRange.UTCDateTime.parse(\"2020-02-02T00:01:00Z..2020-02-02T00:01:01Z\")\n{:ok, %Ecto.DateTimeRange.UTCDateTime{start_at: ~U[2020-02-02T00:01:00Z], end_at: ~U[2020-02-02T00:01:01Z]}}\n\niex> Ecto.DateTimeRange.UTCDateTime.parse(\"2020-02-02T00:01:00Z..later\")\n{:error, \"Unable to parse DateTime(s) from input\"}\n```","title":"Example - Ecto.DateTimeRange.UTCDateTime.parse/1","ref":"Ecto.DateTimeRange.UTCDateTime.html#parse/1-example"},{"type":"type","doc":"","title":"Ecto.DateTimeRange.UTCDateTime.t/0","ref":"Ecto.DateTimeRange.UTCDateTime.html#t:t/0"},{"type":"function","doc":"Declares the native type that will be used in the database.","title":"Ecto.DateTimeRange.UTCDateTime.type/0","ref":"Ecto.DateTimeRange.UTCDateTime.html#type/0"},{"type":"module","doc":"Provides operators for querying against ranges in PostgreSQL.","title":"Ecto.DateTimeRange.Operators","ref":"Ecto.DateTimeRange.Operators.html"},{"type":"module","doc":"```\nimport Ecto.Query\nimport Ecto.DateTimeRange.Operators\n\nnow = DateTime.utc_now()\nfrom(thing in Thing, where: contains(thing.during, ^now))\n```","title":"Usage - Ecto.DateTimeRange.Operators","ref":"Ecto.DateTimeRange.Operators.html#module-usage"},{"type":"macro","doc":"Filter by rows where the given datetime falls within the range.","title":"Ecto.DateTimeRange.Operators.contains/2","ref":"Ecto.DateTimeRange.Operators.html#contains/2"},{"type":"macro","doc":"```\nfrom(thing in Thing, where: contains(thing.during_utc, ^DateTime.utc_now()))\n```","title":"Examples - Ecto.DateTimeRange.Operators.contains/2","ref":"Ecto.DateTimeRange.Operators.html#contains/2-examples"},{"type":"extras","doc":"# Overview\n\n`Ecto DateTimeRange` is a library extending Ecto with field types to handle PostgreSQL column types\nencapsulating timestamp ranges. The types provided by this library can be paired with view\ncomponents in order to facilitate editing ranges in forms.","title":"Overview","ref":"overview.html"},{"type":"extras","doc":"Add the [hex package](https://hex.pm/packages/ecto_date_time_range) to `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ecto_date_time_range, \"~> 0.1\"}\n  ]\nend\n```\n\nIf `DateTime`s will be shifted between time zones at any point during the value's lifecycle, for\ninstance to show/edit timestamps in the time zone reported by a person's browser, then a time zone\ndatabase must also be added and configured as Elixir's `:time_zone_database`.\n\n- https://github.com/mathieuprog/tz\n- https://github.com/lau/tzdata","title":"Installation - Overview","ref":"overview.html#installation"},{"type":"extras","doc":"Add [migrations](migrations.md) using `:tstzrange` column types.\n\n```elixir\ndefmodule Core.Repo.Migrations.AddThings do\n  use Ecto.Migration\n\n  def change do\n    create table(:things) do\n      add :performed_during, :tstzrange\n    end\n\n    create table(:thing_schedules) do\n      add :performed_every, :tsrange\n    end\n  end\nend\n```\n\nFor more detailed information see the [migrations guide](migrations.md).","title":"Migrations - Overview","ref":"overview.html#migrations"},{"type":"extras","doc":"```elixir\ndefmodule Core.Thing do\n  use Ecto.Schema\n  import Ecto.Changeset\n\n  schema \"things\" do\n    field :performed_during, Ecto.DateTimeRange.UTCDateTime\n  end\n\n  @required_attrs ~w[performed_during]a\n  def changeset(data \\\\ %__MODULE__{}, attrs) do\n    data\n    |> cast(attrs, @required_attrs)\n    |> validate_required(@required_attrs)\n  end\nend\n```\n\n```elixir\ndefmodule Core.ThingSchedule do\n  use Ecto.Schema\n  import Ecto.Changeset\n\n  schema \"thing_scheduless\" do\n    field :performed_every, Ecto.DateTimeRange.Time\n  end\n\n  @required_attrs ~w[performed_every]a\n  def changeset(data \\\\ %__MODULE__{}, attrs) do\n    data\n    |> cast(attrs, @required_attrs)\n    |> validate_required(@required_attrs)\n  end\nend\n```","title":"Schemas - Overview","ref":"overview.html#schemas"},{"type":"extras","doc":"# Migrations\n\n`Ecto.UTCDateTime` ranges can be indicated in migrations with the `:tstzrange` column type.\n\n```elixir\ndefmodule Core.Repo.Migrations.AddThings do\n  use Ecto.Migration\n\n  def change do\n    create table(:things) do\n      add :profile_id, references(:profiles), null: false\n      add :performed_during, :tstzrange\n    end\n  end\nend\n```\n\n`Ecto.DateTime.Time` ranges can be indicated in migrations with the `:tsrange` column type.\n\n```elixir\ndefmodule Core.Repo.Migrations.AddThings do\n  use Ecto.Migration\n\n  def change do\n    create table(:things) do\n      add :profile_id, references(:profiles), null: false\n      add :performed_every, :tsrange\n    end\n  end\nend\n```","title":"Migrations","ref":"migrations.html"},{"type":"extras","doc":"`GIST` or `SP-GIST` indexes and constraints can include range operators:\n\n```elixir\ndefmodule Core.Repo.Migrations.ExcludeOverlappingThings do\n  use Ecto.Migration\n\n  def change do\n    create constraint(\n             :things,\n             :no_overlapping_things,\n             exclude: ~s|gist (profile_id with =, performed_during with &&)|\n           )\n  end\nend\n```","title":"Indexes - Migrations","ref":"migrations.html#indexes"},{"type":"extras","doc":"# Form Data\n\nTypes provided by this library are intended to be used with nested form data that can be cast to\nranges as a single unit. For example, a heex component could be written as follows:\n\n```elixir\ndefmodule Web.Components do\n  use Phoenix.HTML\n\n  import Phoenix.LiveView.Helpers\n\n  def utc_date_time_range_field(assigns) do\n    ~H\"\"\"\n     \n      <%= error_tag @f, @field %>\n       \n       \n       \n     \n    \"\"\"\n  end\n\n  def time_range_field(assigns) do\n  ~H\"\"\"\n   \n     \n      <%= error_tag @f, @field %>\n       \n       \n     \n   \n  \"\"\"\n  end\n\n  defp form_name(form), do: form.name\n\n  defp utc_date_time_part(form, field, part) do\n    form.source\n    |> Ecto.Changeset.get_field(field)\n    |> case do\n      nil -> DateTime.utc_now()\n      %Ecto.DateTimeRange.UTCDateTime{} = range -> Map.get(range, part) |> to_time_zone(\"America/Los_Angeles\")\n    end\n  end\n\n  defp time_part(form, field, part) do\n    form.source\n    |> Ecto.Changeset.get_field(field)\n    |> case do\n      nil -> default_time(part)\n      %Ecto.DateTimeRange.Time{} = range -> Map.get(range, part)\n    end\n    |> to_time_value()\n  end\n\n  defp default_time(:start_at), do: ~T[06:00:00]\n  defp default_time(:end_at), do: ~T[18:00:00]\n\n  defp to_time_value(%Time{} = time), do: Calendar.strftime(time, \"%H:%M\")\n\n  defp to_time_zone(%DateTime{} = time, tz), do: DateTime.add(time, tz_offset(tz), :second)\n\n  defp tz_offset(tz) do\n    {:ok, %{std_offset: _, utc_offset: offset, zone_abbr: _}} =\n      Calendar.get_time_zone_database().time_zone_periods_from_wall_datetime(DateTime.utc_now(), tz)\n\n    offset\n  end\nend\n```\n\nComponents such as this can be used in a parent live view:\n\n```elixir\ndefmodule Web.MyLiveView do\n  use Web, :live_view\n  import Web.Components\n\n  @impl Phoenix.LiveView\n  def render(assigns) do\n    ~H\"\"\"\n    <.form let={f} for={@changeset} id=\"thing-form\" phx-change=\"validate\">\n      <.utc_date_time_range_field id=\"performed-during\" f={f} field={:performed_during} />\n      <%= submit(\"Save\") %>\n    </.form>\n    \"\"\"\n  end\n\n  @impl Phoenix.LiveView\n  def mount(_params, _session, socket) do\n    socket =\n      socket\n      |> assign(:changeset, Core.Thing.changeset(%{}))\n\n    {:ok, socket}\n  end\n\n  @impl Phoenix.LiveView\n  def handle_event(\"validate\", %{\"thing\" => params}, socket) do\n    socket = socket |> assign(changeset: Core.Things.changeset(params))\n    {:noreply, socket}\n  end\n\nend\n```\n\nWhen this form is sent to the server via `POST` or in a LiveView's `phx-change` or `phx-submit`, the\nparams will arrive in the following format, which matches that expected by\n`Ecto.DateTimeRange.UTCDateTime.cast/1`:\n\n```elixir\n%{\n  \"thing\" => %{\n    \"performed_during\" => %{\n        \"start_at\" => \"2022-06-22 01:00:00\",\n        \"end_at\" => \"2022-06-22 01:00:00\",\n        \"tz\" => \"Etc/UTC\"\n      }\n  }\n}\n```","title":"Form Data","ref":"forms.html"},{"type":"extras","doc":"# Change Log","title":"Change Log","ref":"changelog.html"},{"type":"extras","doc":"","title":"Unreleased - Change Log","ref":"changelog.html#unreleased"},{"type":"extras","doc":"- Test against Elixir 1.18.\n- **Breaking change:** Drop support for Elixir 1.15.","title":"2.0.0 - Change Log","ref":"changelog.html#2-0-0"},{"type":"extras","doc":"- require Elixir 1.15 or greater\n- test against the latest version of Erlang and Elixir","title":"1.3.0 - Change Log","ref":"changelog.html#1-3-0"},{"type":"extras","doc":"- Updated dependencies.","title":"1.2.2 - Change Log","ref":"changelog.html#1-2-2"},{"type":"extras","doc":"- Relax version matching of `tz` when present.","title":"1.2.1 - Change Log","ref":"changelog.html#1-2-1"},{"type":"extras","doc":"- Documentation TOC organization.\n- Add `Ecto.DateTimeRange.NaiveDateTime`.","title":"1.2.0 - Change Log","ref":"changelog.html#1-2-0"},{"type":"extras","doc":"- `Ecto.DateTimeRange.Time.contains?/2` handles `DateTime` and `NaiveDateTime` values.","title":"1.1.0 - Change Log","ref":"changelog.html#1-1-0"},{"type":"extras","doc":"**Breaking Changes**\n\n- Remove `Ecto.UTCDateTimeRange` and `Ecto.UTCTimeRange`.\n- Changes `sigil_t`:\n  - Defaults to `Ecto.DateTimeRange.UTCDateTime`.\n  - Changes `U` modifier to return `Ecto.DateTimeRange.UTCDateTime`.\n  - Changes `T` modifier to return `Ecto.DateTimeRange.Time`.\n\n**Upgrading**\n\n1. Update to version `0.99.0`.\n1. Fix all deprecation warnings by switching code to use `Ecto.DateTimeRange.UTCDateTime` instead of\n  `Ecto.UTCDateTimeRange` and `Ecto.DateTimeRange.Time` instead of `Ecto.UTCTimeRange`. **Important:**\n  when using time ranges, `tz` is ignored when provided in form params, and no time zone casting is\n  applied. Any time zone logic must be applied in application code.\n1. Switch usage of `sigil_t` to use the `u` or `t` modifiers, specifying the new modules.\n1. Update to version `1.0.0`.\n1. Switch usage of `sigil_t` to use the `U` or `T` modifiers.","title":"1.0.0 - Change Log","ref":"changelog.html#1-0-0"},{"type":"extras","doc":"- Deprecate `Ecto.UTCDateTimeRange` and `Ecto.UTCTimeRange`.\n- Add `Ecto.DateTimeRange.UTCDateTime` type.\n\nThis release represents the last `0.x` version.","title":"0.99.0 - Change Log","ref":"changelog.html#0-99-0"},{"type":"extras","doc":"- Add `Ecto.DateTimeRange.Time` type, representing a naive time range.","title":"0.4.0 - Change Log","ref":"changelog.html#0-4-0"},{"type":"extras","doc":"- Fix `Ecto.UTCTimeRange.contains?/2` to handle ranges crossing day barrier.","title":"0.3.1 - Change Log","ref":"changelog.html#0-3-1"},{"type":"extras","doc":"- Add `Ecto.UTCDateTimeRange.contains?/2`.\n- Add `Ecto.UTCTimeRange.contains?/2`.","title":"0.3.0 - Change Log","ref":"changelog.html#0-3-0"},{"type":"extras","doc":"- Move `~t` to `Ecto.DateTimeRange`.\n- Add `Ecto.UTCTimeRange` type.\n- Add `Ecto.RangeOperators.contains/2` macro.","title":"0.2.0 - Change Log","ref":"changelog.html#0-2-0"},{"type":"extras","doc":"- Update docs regarding setup, form data.\n- Clarify errors in UTCDateTimeRange's `sigil_t` and `parse`.","title":"0.1.1 - Change Log","ref":"changelog.html#0-1-1"},{"type":"extras","doc":"- Initial release of `Ecto.UTCDateTimeRange`.","title":"0.1.0 - Change Log","ref":"changelog.html#0-1-0"},{"type":"extras","doc":"Copyright 2022 synchronal.dev\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use this file except in\ncompliance with the License. You may obtain a copy of the License at\n\n http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software distributed under the License is\ndistributed on an \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\nimplied. See the License for the specific language governing permissions and limitations under the\nLicense.","title":"LICENSE","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}